@@ -63,8 +63,10 @@ kind! {
     ArrayInitIndexExpr,
     ArrayInitLoopExpr,
     ArraySubscriptExpr,
+    ArrayTypeTraitExpr,
     AsmLabelAttr,
     AtomicExpr,
+    AtomicType,
     AttributedStmt,
     AttributedType,
     AutoType,
@@ -73,6 +75,7 @@ kind! {
     BindingDecl,
     BlockPointerType,
     BreakStmt,
+    BuiltinAttr,
     BuiltinBitCastExpr,
     BuiltinTemplateDecl,
     BuiltinType,
@@ -211,6 +214,7 @@ kind! {
     PointerAttr,
     PointerType,
     PredefinedExpr,
+    PreferredNameAttr,
     PureAttr,
     QualType,
     RValueReferenceType,
@@ -242,6 +246,7 @@ kind! {
     UnaryExprOrTypeTraitExpr,
     UnaryOperator,
     UnaryTransformType,
+    UnavailableAttr,
     UnresolvedLookupExpr,
     UnresolvedMemberExpr,
     UnresolvedUsingTypenameDecl,
@@ -249,6 +254,7 @@ kind! {
     UnusedAttr,
     UsingDecl,
     UsingDirectiveDecl,
+    UsingIfExistsAttr,
     UsingShadowDecl,
     VarDecl,
     VarTemplateDecl,
