@@ -1,7 +1,6 @@
 #![allow(
     clippy::large_enum_variant,
     clippy::let_underscore_drop,
-    clippy::pub_enum_variant_names,
     clippy::struct_excessive_bools
 )]
 
@@ -24,8 +23,10 @@ pub enum Clang {
     ArrayInitIndexExpr(ArrayInitIndexExpr),
     ArrayInitLoopExpr(ArrayInitLoopExpr),
     ArraySubscriptExpr(ArraySubscriptExpr),
+    ArrayTypeTraitExpr(ArrayTypeTraitExpr),
     AsmLabelAttr(AsmLabelAttr),
     AtomicExpr(AtomicExpr),
+    AtomicType(AtomicType),
     AttributedStmt(AttributedStmt),
     AttributedType(AttributedType),
     AutoType(AutoType),
@@ -34,6 +35,7 @@ pub enum Clang {
     BindingDecl(BindingDecl),
     BlockPointerType(BlockPointerType),
     BreakStmt(BreakStmt),
+    BuiltinAttr(BuiltinAttr),
     BuiltinBitCastExpr(BuiltinBitCastExpr),
     BuiltinTemplateDecl(BuiltinTemplateDecl),
     BuiltinType(BuiltinType),
@@ -172,6 +174,7 @@ pub enum Clang {
     PointerAttr(PointerAttr),
     PointerType(PointerType),
     PredefinedExpr(PredefinedExpr),
+    PreferredNameAttr(PreferredNameAttr),
     PureAttr(PureAttr),
     QualType(QualType),
     RValueReferenceType(RValueReferenceType),
@@ -203,6 +206,7 @@ pub enum Clang {
     UnaryExprOrTypeTraitExpr(UnaryExprOrTypeTraitExpr),
     UnaryOperator(UnaryOperator),
     UnaryTransformType(UnaryTransformType),
+    UnavailableAttr(UnavailableAttr),
     UnresolvedLookupExpr(UnresolvedLookupExpr),
     UnresolvedMemberExpr(UnresolvedMemberExpr),
     UnresolvedUsingTypenameDecl(UnresolvedUsingTypenameDecl),
@@ -210,6 +214,7 @@ pub enum Clang {
     UnusedAttr(UnusedAttr),
     UsingDecl(UsingDecl),
     UsingDirectiveDecl(UsingDirectiveDecl),
+    UsingIfExistsAttr(UsingIfExistsAttr),
     UsingShadowDecl(UsingShadowDecl),
     VarDecl(VarDecl),
     VarTemplateDecl(VarTemplateDecl),
@@ -313,6 +318,16 @@ pub struct ArraySubscriptExpr {
     pub value_category: ValueCategory,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct ArrayTypeTraitExpr {
+    pub range: SourceRange,
+    pub r#type: Type,
+    #[serde(rename = "valueCategory")]
+    pub value_category: ValueCategory,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -330,6 +345,13 @@ pub struct AtomicExpr {
     pub value_category: ValueCategory,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct AtomicType {
+    pub r#type: Type,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -380,7 +402,7 @@ pub struct BindingDecl {
     pub range: SourceRange,
     #[serde(rename = "isReferenced", default)]
     pub is_referenced: bool,
-    name: Box<str>,
+    pub name: Box<str>,
 }
 
 #[derive(Deserialize, Debug)]
@@ -401,6 +423,17 @@ pub struct BreakStmt {
     pub range: SourceRange,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct BuiltinAttr {
+    pub range: SourceRange,
+    #[serde(default)]
+    pub inherited: bool,
+    #[serde(default)]
+    pub implicit: bool,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1316,6 +1349,8 @@ pub struct DependentTemplateSpecializationType {
     pub is_dependent: bool,
     #[serde(rename = "isInstantiationDependent", default)]
     pub is_instantiation_dependent: bool,
+    #[serde(rename = "containsUnexpandedPack", default)]
+    pub contains_unexpanded_pack: bool,
 }
 
 #[derive(Deserialize, Debug)]
@@ -1746,6 +1781,8 @@ pub struct LValueReferenceType {
     pub is_dependent: bool,
     #[serde(rename = "isInstantiationDependent", default)]
     pub is_instantiation_dependent: bool,
+    #[serde(rename = "containsUnexpandedPack", default)]
+    pub contains_unexpanded_pack: bool,
 }
 
 #[derive(Deserialize, Debug)]
@@ -2088,6 +2125,15 @@ pub struct PredefinedExpr {
     pub name: Box<str>,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct PreferredNameAttr {
+    pub range: SourceRange,
+    #[serde(default)]
+    pub inherited: bool,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -2460,6 +2506,13 @@ pub struct UnaryTransformType {
     pub transform_kind: UnaryTransformTypeKind,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct UnavailableAttr {
+    pub range: SourceRange,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -2535,6 +2588,13 @@ pub struct UsingDirectiveDecl {
     pub nominated_namespace: Decl,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct UsingIfExistsAttr {
+    pub range: SourceRange,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -3607,6 +3667,8 @@ pub enum ValueCategory {
     XValue,
     #[serde(rename = "rvalue")]
     RValue,
+    #[serde(rename = "prvalue")]
+    PRValue,
 }
 
 fn default_true() -> bool {
